@@ -1,18 +1,15 @@
-# @(#)Ident: FileData.pm 2013-11-22 18:57 pjf ;
-
 package Yakuake::Sessions::TraitFor::FileData;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
-use Class::Usul::Functions  qw( throw );
+use Class::Usul::Functions  qw( io throw );
 use File::DataClass::Types  qw( Bool );
 use Moo::Role;
 use Class::Usul::Options;
 
 requires qw( add_leader apply_sessions config debug debug_flag dumper file
-             get_sessions_from_yakuake io loc options next_argv
+             get_sessions_from_yakuake loc options next_argv
              profile_path run_cmd storage_class yorn );
 
 # Public attributes
@@ -27,7 +24,7 @@ sub dump : method {
    my $session_tabs = $self->get_sessions_from_yakuake;
 
    ($self->debug or not $path) and $self->dumper( $session_tabs );
-   $path or return OK; $path = $self->io( $path );
+   $path or return OK; $path = io $path;
 
    my $prompt; $path->exists and $path->is_file and not $self->force
       and $prompt = $self->loc( 'Specified file exists, overwrite?' )
@@ -44,7 +41,8 @@ sub load : method {
    my ($self, $data_only) = @_; my $path = $self->profile_path;
 
    $path->exists and $path->is_file
-      or throw $self->loc( 'Path [_1] does not exist or is not a file', $path );
+      or throw error => 'Path [_1] does not exist or is not a file',
+               args  => [ $path ];
 
    $data_only and return $self->_get_sessions_from_file;
 
@@ -54,9 +52,9 @@ sub load : method {
 
    my $cmd  = 'nohup '.$self->config->pathname.SPC.$self->debug_flag;
       $cmd .= " -o detached=1 load ${path}";
-   my $out  = $self->config->logsdir->catfile( 'load_session.out' );
+   my $out  = $self->config->tempdir->catfile( 'load_session.out' );
 
-   $self->run_cmd( $cmd, { async => TRUE, out => $out, err => q(out), } );
+   $self->run_cmd( $cmd, { async => TRUE, out => $out, err => 'out', } );
    return OK;
 }
 
@@ -67,7 +65,7 @@ sub _get_sessions_from_file {
    my $tabs = $self->file->data_load
       ( paths => [ $path ], storage_class => $self->storage_class )->{sessions};
 
-   $tabs->[ 0 ] or throw $self->loc( 'No session tabs info found' );
+   $tabs->[ 0 ] or throw 'No session tabs info found';
 
    return $tabs;
 }
@@ -91,11 +89,6 @@ Yakuake::Sessions::TraitFor::FileData - Dumps and loads session data
    extends 'Yakuake::Sessions::Base';
    with    'Yakuake::Sessions::TraitFor::FileData';
 
-=head1 Version
-
-This documents version v0.11.$Rev: 1 $ of
-L<Yakuake::Sessions::TraitFor::FileData>
-
 =head1 Description
 
 This is a L<Moo::Role> which dumps and loads session data
@@ -165,7 +158,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2014 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
